nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Esr1

Struct Esr1 

#[repr(transparent)]
pub struct Esr1(pub u32);
Error and Status 1 Register

Tuple Fields

0: u32

Implementations

Source

impl Esr1

pub const fn wakint(&self) -> bool

Wake-Up Interrupt

pub const fn set_wakint(&mut self, val: bool)

Wake-Up Interrupt

pub const fn errint(&self) -> bool

Error Interrupt

pub const fn set_errint(&mut self, val: bool)

Error Interrupt

pub const fn boffint(&self) -> bool

Bus Off Interrupt

pub const fn set_boffint(&mut self, val: bool)

Bus Off Interrupt

pub const fn rx(&self) -> bool

FlexCAN In Reception

pub const fn set_rx(&mut self, val: bool)

FlexCAN In Reception

pub const fn fltconf(&self) -> Fltconf

Fault Confinement State

pub const fn set_fltconf(&mut self, val: Fltconf)

Fault Confinement State

pub const fn tx(&self) -> Tx

FlexCAN In Transmission

pub const fn set_tx(&mut self, val: Tx)

FlexCAN In Transmission

pub const fn idle(&self) -> Idle

IDLE

pub const fn set_idle(&mut self, val: Idle)

IDLE

pub const fn rxwrn(&self) -> Rxwrn

Rx Error Warning

pub const fn set_rxwrn(&mut self, val: Rxwrn)

Rx Error Warning

pub const fn txwrn(&self) -> Txwrn

TX Error Warning

pub const fn set_txwrn(&mut self, val: Txwrn)

TX Error Warning

pub const fn stferr(&self) -> Stferr

Stuffing Error

pub const fn set_stferr(&mut self, val: Stferr)

Stuffing Error

pub const fn frmerr(&self) -> Frmerr

Form Error

pub const fn set_frmerr(&mut self, val: Frmerr)

Form Error

pub const fn crcerr(&self) -> Crcerr

Cyclic Redundancy Check Error

pub const fn set_crcerr(&mut self, val: Crcerr)

Cyclic Redundancy Check Error

pub const fn ackerr(&self) -> Ackerr

Acknowledge Error

pub const fn set_ackerr(&mut self, val: Ackerr)

Acknowledge Error

pub const fn bit0err(&self) -> Bit0err

Bit0 Error

pub const fn set_bit0err(&mut self, val: Bit0err)

Bit0 Error

pub const fn bit1err(&self) -> Bit1err

Bit1 Error

pub const fn set_bit1err(&mut self, val: Bit1err)

Bit1 Error

pub const fn rwrnint(&self) -> Rwrnint

Rx Warning Interrupt Flag

pub const fn set_rwrnint(&mut self, val: Rwrnint)

Rx Warning Interrupt Flag

pub const fn twrnint(&self) -> Twrnint

Tx Warning Interrupt Flag

pub const fn set_twrnint(&mut self, val: Twrnint)

Tx Warning Interrupt Flag

pub const fn synch(&self) -> Synch

CAN Synchronization Status

pub const fn set_synch(&mut self, val: Synch)

CAN Synchronization Status

pub const fn boffdoneint(&self) -> Boffdoneint

Bus Off Done Interrupt

pub const fn set_boffdoneint(&mut self, val: Boffdoneint)

Bus Off Done Interrupt

pub const fn errint_fast(&self) -> ErrintFast

Error interrupt for errors detected in Data Phase of CAN FD frames with BRS bit set

pub const fn set_errint_fast(&mut self, val: ErrintFast)

Error interrupt for errors detected in Data Phase of CAN FD frames with BRS bit set

pub const fn errovr(&self) -> Errovr

Error Overrun

pub const fn set_errovr(&mut self, val: Errovr)

Error Overrun

pub const fn stferr_fast(&self) -> StferrFast

Stuffing Error in the Data Phase of CAN FD frames with the BRS bit set

pub const fn set_stferr_fast(&mut self, val: StferrFast)

Stuffing Error in the Data Phase of CAN FD frames with the BRS bit set

pub const fn frmerr_fast(&self) -> FrmerrFast

Form Error in the Data Phase of CAN FD frames with the BRS bit set

pub const fn set_frmerr_fast(&mut self, val: FrmerrFast)

Form Error in the Data Phase of CAN FD frames with the BRS bit set

pub const fn crcerr_fast(&self) -> CrcerrFast

Cyclic Redundancy Check Error in the CRC field of CAN FD frames with the BRS bit set

pub const fn set_crcerr_fast(&mut self, val: CrcerrFast)

Cyclic Redundancy Check Error in the CRC field of CAN FD frames with the BRS bit set

pub const fn bit0err_fast(&self) -> Bit0errFast

Bit0 Error in the Data Phase of CAN FD frames with the BRS bit set

pub const fn set_bit0err_fast(&mut self, val: Bit0errFast)

Bit0 Error in the Data Phase of CAN FD frames with the BRS bit set

pub const fn bit1err_fast(&self) -> Bit1errFast

Bit1 Error in the Data Phase of CAN FD frames with the BRS bit set

pub const fn set_bit1err_fast(&mut self, val: Bit1errFast)

Bit1 Error in the Data Phase of CAN FD frames with the BRS bit set