nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Id57

Struct Id57 

#[repr(transparent)]
pub struct Id57(pub u32);
Message Buffer 57 ID Register

Tuple Fields

0: u32

Implementations

Source

impl Id57

pub const fn ext(&self) -> u32

Contains extended (LOW word) identifier of message buffer.

pub const fn set_ext(&mut self, val: u32)

Contains extended (LOW word) identifier of message buffer.

pub const fn std(&self) -> u16

Contains standard/extended (HIGH word) identifier of message buffer.

pub const fn set_std(&mut self, val: u16)

Contains standard/extended (HIGH word) identifier of message buffer.

pub const fn prio(&self) -> u8

Local priority. This 3-bit fieldis only used when LPRIO_EN bit is set in MCR and it only makes sense for Tx buffers. These bits are not transmitted. They are appended to the regular ID to define the transmission priority.

pub const fn set_prio(&mut self, val: u8)

Local priority. This 3-bit fieldis only used when LPRIO_EN bit is set in MCR and it only makes sense for Tx buffers. These bits are not transmitted. They are appended to the regular ID to define the transmission priority.