nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Mb332bCsH

Struct Mb332bCsH 

#[repr(transparent)]
pub struct Mb332bCsH(pub u32);
Message Buffer 3 CS Register

Tuple Fields

0: u32

Implementations

Source

impl Mb332bCsH

pub const fn time_stamp(&self) -> u16

Free-Running Counter Time stamp. This 16-bit field is a copy of the Free-Running Timer, captured for Tx and Rx frames at the time when the beginning of the Identifier field appears on the CAN bus.

pub const fn set_time_stamp(&mut self, val: u16)

Free-Running Counter Time stamp. This 16-bit field is a copy of the Free-Running Timer, captured for Tx and Rx frames at the time when the beginning of the Identifier field appears on the CAN bus.

pub const fn dlc(&self) -> u8

Length of the data to be stored/transmitted.

pub const fn set_dlc(&mut self, val: u8)

Length of the data to be stored/transmitted.

pub const fn rtr(&self) -> bool

Remote Transmission Request. One/zero for remote/data frame.

pub const fn set_rtr(&mut self, val: bool)

Remote Transmission Request. One/zero for remote/data frame.

pub const fn ide(&self) -> bool

ID Extended. One/zero for extended/standard format frame.

pub const fn set_ide(&mut self, val: bool)

ID Extended. One/zero for extended/standard format frame.

pub const fn srr(&self) -> bool

Substitute Remote Request. Contains a fixed recessive bit.

pub const fn set_srr(&mut self, val: bool)

Substitute Remote Request. Contains a fixed recessive bit.

pub const fn code(&self) -> u8

Message Buffer Code. This 4-bit field can be accessed (read or write) by the CPU and by the FlexCAN module itself, as part of the message buffer matching and arbitration process.

pub const fn set_code(&mut self, val: u8)

Message Buffer Code. This 4-bit field can be accessed (read or write) by the CPU and by the FlexCAN module itself, as part of the message buffer matching and arbitration process.

pub const fn esi(&self) -> bool

Error State Indicator. This bit indicates if the transmitting node is error active or error passive.

pub const fn set_esi(&mut self, val: bool)

Error State Indicator. This bit indicates if the transmitting node is error active or error passive.

pub const fn brs(&self) -> bool

Bit Rate Switch. This bit defines whether the bit rate is switched inside a CAN FD format frame.

pub const fn set_brs(&mut self, val: bool)

Bit Rate Switch. This bit defines whether the bit rate is switched inside a CAN FD format frame.

pub const fn edl(&self) -> bool

Extended Data Length. This bit distinguishes between CAN format and CAN FD format frames. The EDL bit must not be set for Message Buffers configured to RANSWER with code field 0b1010.

pub const fn set_edl(&mut self, val: bool)

Extended Data Length. This bit distinguishes between CAN format and CAN FD format frames. The EDL bit must not be set for Message Buffers configured to RANSWER with code field 0b1010.